/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.p4java.extension.path;

/**
 * 
 * @since 2012.1
 */
public enum PathStringFormat {

    ENQUOTE {
	@Override
	public String modify(String path) {
	    return (path.contains(" ") && !path.startsWith("\"")) ? ("\""
		    + path + "\"") : path;
	}
    },

    ESCAPE {
	@Override
	public String modify(String path) {
	    path = path.replace("%", "%25").replace("@", "%40")
		    .replace("#", "%23").replace("*", "%2A");

	    if (path.length() > QUOTE.length() && path.startsWith(QUOTE)
		    && path.endsWith(QUOTE)) {
		path = QUOTE
			+ path.substring(1, path.length() - 1).replace(QUOTE,
				ESCQUOTE) + QUOTE;
	    } else {
		path = path.replace(QUOTE, ESCQUOTE);
	    }
	    return path;
	}
    },

    UNESCAPE {
	@Override
	public String modify(String path) {
	    path = path.replace("%40", "@").replace("%23", "#")
		    .replace("%2A", "*").replace("%25", "%");

	    if (path.length() > ESCQUOTE.length() && path.startsWith(ESCQUOTE)
		    && path.endsWith(ESCQUOTE)) {
		path = ESCQUOTE
			+ path.substring(1, path.length() - 1).replace(
				ESCQUOTE, QUOTE) + ESCQUOTE;
	    } else {
		path = path.replace(ESCQUOTE, QUOTE);
	    }
	    return path;
	}
    },

    UNENQUOTE {
	@Override
	public String modify(String path) {
	    if (path.startsWith("\"") && path.endsWith("\"")) {
		return path.substring(1, path.length() - 1);
	    }
	    return path;
	}
    };

    abstract public String modify(String path);

    final static String QUOTE = "\"";
    final static String ESCQUOTE = "%22";
}
